function [X_tfct,correc] = tfct_analyse(x,Lfen,hop_a)
% [X_tfct,correc] = tfct_analyse(x[,Lfen,hop_a])
% -----------------------------------------------
%
% Fonction d'analyse par tfct d'un signal. Elle renvoie la matrice de TFCT
% ainsi que le coefficient correcteur  appliquer lors de la resynthse du
% signal.
%
% INPUTS
% ******
% - x      : Son  analyser (vecteur Nx1)
% - Lfen   : Longueur de la fenetre d'analyse (512 par dfaut)
% - hop_a  : Incrment d'analyse (Lfen/4 par dfaut)
%
% OUTPUTS
% *******
% - X_tfct : Matrice issue de la TFCT de dimension Lfen+1 * Ntrames
%            Chaque colonne reprsente un demi-spectre  un instant donn.
% - correc : Coefficient de correction  appliquer lors de la resynthse.
%
% Cr par Thomas Hzard le 23/11/2010
%


% 0. INPUTS et vrifications
% **************************
if (nargin < 2)
  Lfen = 512;
end
if (nargin < 3)
  hop_a = round(1/4 * Lfen);
end
if size(x,2) ~= 1
  error('Erreur dimension du signal  analyser');
end

% 1. Initialisation des variables pour l'analyse
% **********************************************
L = length(x);                      % longueur du signal
M = Lfen;                           % longueur de la fentre
w = hanning(M,'periodic');          % dfinition de la fenetre d'analyse
ws = w;                             % dfinition de la fenetre de synthse
I = hop_a;                          % incrment sur les temps d'analyse
N = 2*M;                            % ordre de la tfd
N2 = N/2+1;                         % nombre de canaux de la tfd  
Nt = fix( (L-M)/I );                % nombre de trames
X_tfct = zeros(N2,Nt-1);            % matrice de la tfct

% 2. Calcul du coefficient de correction
% **************************************
output = ola(w.*ws,I,100);            % calcul du coefficient de
correc = mean(output(10*I:end-10*I)); % normalisation

% 3. Analyse par tfct du signal audio
% ***********************************
for r = 1:Nt-1;
  deb = (r-1)*I +1;                % dbut de trame
  fin = deb + M-1;                 % fin de trame
  tx = x(deb:fin).*w;              % calcul de la trame  
  X = fft(tx,N);                   % tfd  l'instant b
  X_tfct(:,r) = X(1:N2);           % on ne garde que les nu >0
end

end